@@ -7,7 +7,6 @@ from django.utils.encoding import force_str
 from phonenumbers import phonenumberutil
 
 from phonenumber_field import formfields, modelfields
-from phonenumber_field.modelfields import PhoneNumberField
 from phonenumber_field.phonenumber import PhoneNumber, to_python
 
 from . import models
@@ -203,7 +202,7 @@ class PhoneNumberFieldTestCase(TestCase):
         Required output format is set as string constant to guarantee
         consistent database storage values
         """
-        number = PhoneNumberField()
+        number = modelfields.PhoneNumberField()
         for frmt in ["E164", "RFC3966", "INTERNATIONAL"]:
             with override_settings(PHONENUMBER_DB_FORMAT=frmt):
                 self.assertEqual(
@@ -431,6 +430,14 @@ class RegionPhoneNumberFormFieldTest(SimpleTestCase):
             },
         )
 
+    @override_settings(PHONENUMBER_DEFAULT_REGION="FR")
+    def test_formfield_uses_default_region(self):
+        class PhoneForm(forms.Form):
+            phone_number = formfields.PhoneNumberField()
+
+        form = PhoneForm()
+        self.assertEqual("FR", form.fields["phone_number"].region)
+
 
 class RegionPhoneNumberModelFieldTest(TestCase):
     def test_uses_region(self):
